"""Add EmailVerification model

Revision ID: 09c1ea32f752
Revises: acdea76db028
Create Date: 2023-06-19 17:05:19.942355

"""
import sqlalchemy as sa
from alembic import op

import fief

# revision identifiers, used by Alembic.
revision = "09c1ea32f752"
down_revision = "acdea76db028"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "fief_email_verifications",
        sa.Column("code", sa.String(length=255), nullable=False),
        sa.Column("email", sa.String(length=320), nullable=False),
        sa.Column("user_id", fief.models.generics.GUID(), nullable=False),
        sa.Column("id", fief.models.generics.GUID(), nullable=False),
        sa.Column(
            "created_at",
            fief.models.generics.TIMESTAMPAware(timezone=True),
            server_default=sa.func.now(),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            fief.models.generics.TIMESTAMPAware(timezone=True),
            server_default=sa.func.now(),
            nullable=False,
        ),
        sa.Column(
            "expires_at",
            fief.models.generics.TIMESTAMPAware(timezone=True),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(["user_id"], ["fief_users.id"], ondelete="CASCADE"),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_index(
        op.f("ix_fief_email_verifications_code"),
        "fief_email_verifications",
        ["code"],
        unique=True,
    )
    op.create_index(
        op.f("ix_fief_email_verifications_created_at"),
        "fief_email_verifications",
        ["created_at"],
        unique=False,
    )
    op.create_index(
        op.f("ix_fief_email_verifications_email"),
        "fief_email_verifications",
        ["email"],
        unique=False,
    )
    op.create_index(
        op.f("ix_fief_email_verifications_expires_at"),
        "fief_email_verifications",
        ["expires_at"],
        unique=False,
    )
    op.create_index(
        op.f("ix_fief_email_verifications_updated_at"),
        "fief_email_verifications",
        ["updated_at"],
        unique=False,
    )

    op.add_column(
        "fief_users", sa.Column("email_verified", sa.Boolean(), nullable=True)
    )

    op.execute("UPDATE fief_users SET email_verified = FALSE")

    connection = op.get_bind()
    if connection.dialect.name == "sqlite":
        with op.batch_alter_table("fief_users") as batch_op:
            batch_op.alter_column(
                "email_verified",
                existing_nullable=True,
                nullable=False,
                existing_type=sa.Boolean(),
            )
    else:
        op.alter_column(
            "fief_users",
            "email_verified",
            existing_nullable=True,
            nullable=False,
            existing_type=sa.Boolean(),
        )

    op.create_index(
        op.f("ix_fief_users_email_verified"),
        "fief_users",
        ["email_verified"],
        unique=False,
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(op.f("ix_fief_users_email_verified"), table_name="fief_users")
    op.drop_column("fief_users", "email_verified")
    op.drop_index(
        op.f("ix_fief_email_verifications_updated_at"),
        table_name="fief_email_verifications",
    )
    op.drop_index(
        op.f("ix_fief_email_verifications_expires_at"),
        table_name="fief_email_verifications",
    )
    op.drop_index(
        op.f("ix_fief_email_verifications_email"), table_name="fief_email_verifications"
    )
    op.drop_index(
        op.f("ix_fief_email_verifications_created_at"),
        table_name="fief_email_verifications",
    )
    op.drop_index(
        op.f("ix_fief_email_verifications_code"), table_name="fief_email_verifications"
    )
    op.drop_table("fief_email_verifications")
    # ### end Alembic commands ###
