"""Add email_lower and remove is_verified/is_superuser on User

Revision ID: acdea76db028
Revises: adbe22247f16
Create Date: 2023-06-19 14:22:10.959405

"""
import sqlalchemy as sa
from alembic import op

import fief

# revision identifiers, used by Alembic.
revision = "acdea76db028"
down_revision = "adbe22247f16"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "fief_users", sa.Column("email_lower", sa.String(length=320), nullable=True)
    )

    op.execute("UPDATE fief_users SET email_lower = LOWER(email)")

    connection = op.get_bind()
    if connection.dialect.name == "sqlite":
        with op.batch_alter_table("fief_users") as batch_op:
            batch_op.alter_column("email_lower", existing_nullable=True, nullable=False)
    else:
        op.alter_column(
            "fief_users",
            "email_lower",
            existing_nullable=True,
            nullable=False,
            existing_type=sa.String(length=320),
        )

    op.create_index(
        op.f("ix_fief_users_email_lower"), "fief_users", ["email_lower"], unique=False
    )
    op.drop_column("fief_users", "is_verified")
    op.drop_column("fief_users", "is_superuser")
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "fief_users",
        sa.Column(
            "is_superuser",
            sa.BOOLEAN(),
            autoincrement=False,
            nullable=False,
            server_default=False,
        ),
    )
    op.add_column(
        "fief_users",
        sa.Column(
            "is_verified",
            sa.BOOLEAN(),
            autoincrement=False,
            nullable=False,
            server_default=False,
        ),
    )
    op.drop_index(op.f("ix_fief_users_email_lower"), table_name="fief_users")
    op.drop_column("fief_users", "email_lower")
    # ### end Alembic commands ###
